#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Tests for `democritus` module."""

import pytest

from democritus import democritus


@pytest.fixture
def response():
    return "foo bar"


def test_democritus_initialization():
    assert 1 == 1



#!/usr/bin/env python
# -*- coding: utf-8 -*-

from setuptools import setup, find_packages

with open('README.md') as readme_file:
    readme = readme_file.read()

with open('LICENSE') as license_file:
    license = license_file.read()

requirements = [
    # TODO: put package requirements here
]

test_requirements = [
    # TODO: put package test requirements here
]

setup(
    name='democritus',
    version='2020.08.19',
    description="Future home of democritus project.",
    long_description=readme,
    author="Floyd Hightower",
    author_email='floyd.hightower27@gmail.com',
    url='https://gitlab.com/fhightower/democritus',
    packages=find_packages(exclude=('tests', 'docs')),
    include_package_data=True,
    install_requires=requirements,
    license=license,
    zip_safe=True,
    keywords='democritus',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
